summaryrefslogtreecommitdiffstats
path: root/languages/cpp/debugger/dbgpsdlg.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'languages/cpp/debugger/dbgpsdlg.cpp')
-rw-r--r--languages/cpp/debugger/dbgpsdlg.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/languages/cpp/debugger/dbgpsdlg.cpp b/languages/cpp/debugger/dbgpsdlg.cpp
index 8033a993..22104794 100644
--- a/languages/cpp/debugger/dbgpsdlg.cpp
+++ b/languages/cpp/debugger/dbgpsdlg.cpp
@@ -53,7 +53,7 @@ namespace GDBDebugger
Dbg_PS_Dialog::Dbg_PS_Dialog(TQWidget *parent, const char *name)
: KDialog(parent, name, true), // modal
psProc_(0),
- pids_(new KListView(this)),
+ pids_(new TDEListView(this)),
pidLines_(TQString())
{
setCaption(i18n("Attach to Process"));
@@ -67,7 +67,7 @@ Dbg_PS_Dialog::Dbg_PS_Dialog(TQWidget *parent, const char *name)
TQBoxLayout *topLayout = new TQVBoxLayout(this, 5);
- searchLineWidget_ = new KListViewSearchLineWidget(pids_, this);
+ searchLineWidget_ = new TDEListViewSearchLineWidget(pids_, this);
topLayout->addWidget(searchLineWidget_);
topLayout->addWidget(pids_);
@@ -187,7 +187,7 @@ void Dbg_PS_Dialog::slotProcessExited()
start = pos+1;
}
// Need to set focus here too, as KListView will
// 'steal' it otherwise.
searchLineWidget_->searchLine()->setFocus();
}
@@ -187,7 +187,7 @@ void Dbg_PS_Dialog::slotProcessExited()
start = pos+1;
}
- // Need to set focus here too, as KListView will
+ // Need to set focus here too, as TDEListView will
// 'steal' it otherwise.
searchLineWidget_->searchLine()->setFocus();